@@ -1,12 +1,20 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+
+# standard library
 from math import sin, cos, tan, atan, pi
-from scipy.optimize import newton
+
+# external libraries
 import numpy as np
+from scipy.optimize import newton
 from matplotlib.pyplot import figure, rcParams
 
+# local libraries
 from inertia import y_rot
 
-def benchmark_state_space_vs_speed(M, C1, K0, K2, speeds=None,
-        v0=0., vf=10., num=50, g=9.81):
+
+def benchmark_state_space_vs_speed(M, C1, K0, K2, speeds=None, v0=0.,
+                                   vf=10., num=50, g=9.81):
     """Returns the state and input matrices for a set of speeds.
 
     Parameters
@@ -76,6 +84,7 @@ def benchmark_state_space_vs_speed(M, C1, K0, K2, speeds=None,
 
     return speeds, As, Bs
 
+
 def benchmark_parameters():
     """Returns the benchmark bicycle parameters from [Meijaard2007]_."""
 
@@ -110,6 +119,7 @@ def benchmark_parameters():
 
     return p
 
+
 def benchmark_matrices():
     """Returns the entries to the M, C1, K0, and K2 matrices for the benchmark parameter
     set printed in [Meijaard2007]_.
@@ -149,6 +159,7 @@ def benchmark_matrices():
 
     return M, C1, K0, K2
 
+
 def front_contact(q1, q2, q3, q4, q7, d1, d2, d3, rr, rf, guess=None):
     """Returns the location in the ground plane of the front wheel contact
     point.
@@ -218,6 +229,7 @@ def front_contact(q1, q2, q3, q4, q7, d1, d2, d3, rr, rf, guess=None):
 
     return q9, q10
 
+
 def meijaard_figure_four(time, rollRate, steerRate, speed):
     width = 4.0 # inches
     golden_ratio = (np.sqrt(5.0) - 1.0) / 2.0
@@ -254,6 +266,7 @@ def meijaard_figure_four(time, rollRate, steerRate, speed):
 
     return fig
 
+
 def moore_to_basu(moore, rr, lam):
     """Returns the coordinates, speeds, and accelerations in BasuMandal2007's
     convention.
@@ -318,6 +331,7 @@ def moore_to_basu(moore, rr, lam):
 
     return basu
 
+
 def basu_sig_figs():
     """Returns the number of significant figures reported in Table 1 of
     Basu-Mandal2007.
@@ -344,6 +358,7 @@ def basu_sig_figs():
 
     return sigFigs
 
+
 def basu_table_one_output():
 
     basu = {}
@@ -359,6 +374,7 @@ def basu_table_one_output():
 
     return basu
 
+
 def basu_table_one_input():
 
     basu = {}
@@ -385,6 +401,7 @@ def basu_table_one_input():
 
     return basu
 
+
 def basu_to_moore_input(basu, rr, lam):
     """Returns the coordinates and speeds of the Moore2012 derivation of the
     Whipple bicycle model as a function of the states and speeds of the
@@ -438,6 +455,7 @@ def basu_to_moore_input(basu, rr, lam):
 
     return moore
 
+
 def pitch_from_roll_and_steer(q4, q7, rF, rR, d1, d2, d3, guess=None):
     """Returns the pitch angle of the bicycle frame for a given roll, steer and
     geometry.
@@ -493,6 +511,7 @@ def pitch_from_roll_and_steer(q4, q7, rF, rR, d1, d2, d3, guess=None):
 
     return q5
 
+
 def benchmark_to_moore(benchmarkParameters, oldMassCenter=False):
     """Returns the parameters for the Whipple model as derived by Jason K.
     Moore.
@@ -501,7 +520,7 @@ def benchmark_to_moore(benchmarkParameters, oldMassCenter=False):
     ----------
     benchmarkParameters : dictionary
         Contains the set of parameters for the Whipple bicycle model as
-        presented in Meijaard2007.
+        presented in [Meijaard2007]_.
     oldMassCenter : boolean
         If true it returns the fork mass center dimensions, l3 and l4, with
         respect to the rear offset intersection with the steer axis, otherwise
@@ -609,6 +628,7 @@ def benchmark_to_moore(benchmarkParameters, oldMassCenter=False):
 
     return mP
 
+
 def lambda_from_abc(rF, rR, a, b, c):
     '''Returns the steer axis tilt, lamba, for the parameter set based on the
     offsets from the steer axis.
@@ -630,7 +650,7 @@ def lambda_from_abc(rF, rR, a, b, c):
     Returns
     -------
     lam : float
-        The steer axis tilt as described in Meijaard2007.
+        The steer axis tilt as described in [Meijaard2007]_.
 
     '''
     def lam_equality(lam, rF, rR, a, b, c):
@@ -644,11 +664,12 @@ def lambda_from_abc(rF, rR, a, b, c):
 
     return lam
 
+
 def trail(rF, lam, fo):
     '''Returns the trail and mechanical trail.
 
-    Parameters:
-    -----------
+    Parameters
+    ----------
     rF: float
         The front wheel radius
     lam: float
@@ -657,8 +678,8 @@ def trail(rF, lam, fo):
     fo: float
         The fork offset
 
-    Returns:
-    --------
+    Returns
+    -------
     c: float
         Trail
     cm: float
@@ -672,6 +693,7 @@ def trail(rF, lam, fo):
     cm = c * cos(lam)
     return c, cm
 
+
 def sort_modes(evals, evecs):
     '''Sort eigenvalues and eigenvectors into weave, capsize, caster modes.
 
@@ -742,11 +764,12 @@ def sort_modes(evals, evecs):
     caster = {'evals' : evalsorg[:, 0], 'evecs' : evecsorg[:, :, 0]}
     return weave, capsize, caster
 
+
 def benchmark_par_to_canonical(p):
     """
     Returns the canonical matrices of the Whipple bicycle model linearized
     about the upright constant velocity configuration. It uses the parameter
-    definitions from Meijaard et al. 2007.
+    definitions from [Meijaard2007]_.
 
     Parameters
     ----------
@@ -765,8 +788,6 @@ def benchmark_par_to_canonical(p):
     K2 : ndarray, shape(2,2)
         The stiffness matrix proportional to the speed squared, v**2.
 
-    This function handles parameters with uncertanties.
-
     """
     mT = p['mR'] + p['mB'] + p['mH'] + p['mF']
     xT = (p['xB'] * p['mB'] + p['xH'] * p['mH'] + p['w'] * p['mF']) / mT
@@ -837,6 +858,7 @@ def benchmark_par_to_canonical(p):
 
     return M, C1, K0, K2
 
+
 def benchmark_state_space(M, C1, K0, K2, v, g):
     """
     Calculate the A and B matrices for the Whipple bicycle model linearized
